Strings and things
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   containers_and_strings.rst
   string_variables.rst
   extracting_characters.rst
   length.rst
   traversal.rst
   runtime_error.rst
   find_function.rst
   own_version_find.rst
   looping_and_counting.rst
   increment_decrement.rst
   string_concatenation.rst
   strings_are_mutable.rst
   strings_are_comparable.rst
   character_classification.rst
   other_string_functions.rst
   glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst
